<?php 
namespace Concrete\Package\MyMitsuMautic\Block\MyMitsuMautic;

use \Concrete\Core\Block\BlockController;
use Core;
class Controller extends BlockController {

    protected $btTable = 'btMyMitsuMautic';
    protected $btInterfaceWidth = '500';
    protected $btInterfaceHeight = '600';
    protected $btDefaultSet = 'form';
    protected $btCacheBlockRecord = true;
    protected $btCacheBlockOutput = true;
    protected $btCacheBlockOutputOnPost = true;
    protected $btCacheBlockOutputForRegisteredUsers = false;
    protected $btCacheBlockOutputLifetime = 0; //until manually updated or cleared

    public function getBlockTypeDescription()
    {
        return t("When visitors do some action, this addon sends to the information to the Mautic, a marketing automation service.");
    }

    public function getBlockTypeName()
    {
        return t("My Mitsu Mautic");
    }

    public function registerViewAssets($outputContent = '')
    {
        $this->requireAsset('javascript', 'jquery');
    }
    
    public function view()
    {
        if ($this->validate_id_class($this->firepoint)) {
            $this->set('firepoint', $this->escape_bracket_for_js($this->firepoint));
        }
        if ($this->validate_id_class($this->urlend)) {
            $this->set('urlend', $this->urlend);
        }
        if ($this->validate_id_class($this->firstname)) {
            $this->set('firstname', $this->escape_bracket_for_js($this->firstname));
        }
        if ($this->validate_id_class($this->lastname)) {
            $this->set('lastname', $this->escape_bracket_for_js($this->lastname));
        }
        if ($this->validate_id_class($this->email)) {
            $this->set('email', $this->escape_bracket_for_js($this->email));
        }
        if(filter_var($this->mauticurl, FILTER_VALIDATE_URL)) {
            $this->set('mauticurl', $this->mauticurl);
        }

    }

    public function escape_bracket_for_js($input) {
        $before = array('[',']');
        $after = array('\\\\[','\\\\]'); // \\ escaped to \. We need 4 \\\\ to add 2 \\.
        return str_replace($before, $after, $input);
    }
    public function validate_id_class($input) {
        $start = substr($input,0,1);
        $item = substr($input,1);
        $allowed_string_attr = 'abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ-_[]';
        if (strlen($start) === strspn($start,'#.') && strlen($item) === strspn($item,$allowed_string_attr) ) {
            return true;
        } else {
            return false;
        }
    }
    
    public function validate($args)
    {
        $e = Core::make('helper/validation/error');

        if(strlen($args['firepoint']) > 255) {
            $e->add(t('firepoint must be at most 255 characters'));
        }
        if(!$this->validate_id_class($args['firepoint'])) {
            $e->add(t('firepoint should be alphanumeric characters with a preceding sharp(#) or dot(.)'));
        }
        
        if(strlen($args['urlend']) > 255) {
            $e->add(t('urlend must be at most 255 characters'));
        }
        if(!$this->validate_id_class($args['urlend'])) {
            $e->add(t('urlend should be alphanumeric characters with a preceding sharp(#) or dot(.)'));
        }
        
        if(strlen($args['firstname']) > 255) {
            $e->add(t('firstname must be at most 255 characters'));
        }
        if(!$this->validate_id_class($args['firstname'])) {
            $e->add(t('firstname should be alphanumeric characters with a preceding sharp(#) or dot(.)'));
        }
        
        if(strlen($args['lastname']) > 255) {
            $e->add(t('lastname must be at most 255 characters'));
        }
        if(!$this->validate_id_class($args['lastname'])) {
            $e->add(t('lastname should be alphanumeric characters with a preceding sharp(#) or dot(.)'));
        }
        
        if(strlen($args['email']) > 255) {
            $e->add(t('email must be at most 255 characters'));
        }
        if(!$this->validate_id_class($args['email'])) {
            $e->add(t('email should be alphanumeric characters with a preceding sharp(#) or dot(.)'));
        }
        if(!filter_var($args['mauticurl'], FILTER_VALIDATE_URL)) {
            $e->add(t('mauticurl should be a URL.'));
        }
        return $e;
    }
}
